@@ -60,7 +60,7 @@ impl SplitText {
                 (Some(_), None) => {
                     prev_font_index_store = font_index_store.clone();
                     true
-                },
+                }
                 _ => false,
             };
 
@@ -69,10 +69,7 @@ impl SplitText {
                     Some(store) => store,
                     None => return Err(Error::NotFoundSpecifiedFontFamily),
                 };
-                glyphs.push(Glyph::new(
-                    *current_range_start..current_range_end,
-                    idx,
-                ));
+                glyphs.push(Glyph::new(*current_range_start..current_range_end, idx));
                 prev_font_index_store = font_index_store;
                 *current_range_start = current_range_end;
             }
@@ -174,7 +171,12 @@ impl TextArea {
         self.0.push(split_text);
     }
 
-    pub(super) fn push_text_with_glyphs(&mut self, text: &str, font: &Font, font_context: &FontContext) -> Result<(), Error> {
+    pub(super) fn push_text_with_glyphs(
+        &mut self,
+        text: &str,
+        font: &Font,
+        font_context: &FontContext,
+    ) -> Result<(), Error> {
         let last_range_end = match self.0.iter().last() {
             Some(split) => split.range.end,
             None => 0,
